@@ -1,12 +1,12 @@
-# Copyrights 1995-2008 by Mark Overmeer <perl@overmeer.net>.
+# Copyrights 1995-2009 by Mark Overmeer <perl@overmeer.net>.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.05.
+# Pod stripped from pm file by OODoc 1.06.
 use strict;
 
 package Mail::Mailer::testfile;
 use vars '$VERSION';
-$VERSION = '2.04';
+$VERSION = '2.05';
 
 use base 'Mail::Mailer::rfc822';
 
@@ -36,7 +36,7 @@ sub close { 1 }
 
 package Mail::Mailer::testfile::pipe;
 use vars '$VERSION';
-$VERSION = '2.04';
+$VERSION = '2.05';
 
 
 sub TIEHANDLE
@@ -46,7 +46,7 @@ sub TIEHANDLE
 
 sub PRINT
 {   my $self = shift;
-    open F, '>>', $Mail::Mailer::testfile::config{outfile};
+    open F, '>>', $Mail::Mailer::testfile::config{outfile} || 'mailer.testfile';
     print F @_;
     close F;
 }
